@@ -4,6 +4,7 @@ from pyhausbus.ResultWorker import ResultWorker
 import pyhausbus.HausBusUtils as HausBusUtils
 from pyhausbus.de.hausbus.homeassistant.proxy.modBusMaster.data.Configuration import Configuration
 from pyhausbus.de.hausbus.homeassistant.proxy.modBusMaster.params.ESensorType import ESensorType
+from pyhausbus.de.hausbus.homeassistant.proxy.modBusMaster.params.EFunction import EFunction
 
 class ModBusMaster(ABusFeature):
   CLASS_ID:int = 45
@@ -56,4 +57,38 @@ class ModBusMaster(ABusFeature):
     hbCommand.send()
     LOGGER.debug("returns")
 
+  """
+  @param node Bus-Knoten Geraete-Adresse.
+  @param function Mod-Bus Funktion.
+  @param address Adresse in Geraet.
+  @param data Daten.
+  """
+  def genericResponse(self, node:int, function:EFunction, address:int, data:bytearray):
+    LOGGER.debug("genericResponse"+" node = "+str(node)+" function = "+str(function)+" address = "+str(address)+" data = "+str(data))
+    hbCommand = HausBusCommand(self.objectId, 129, "genericResponse")
+    hbCommand.addByte(node)
+    hbCommand.addByte(function.value)
+    hbCommand.addWord(address)
+    hbCommand.addBlob(data)
+    ResultWorker()._setResultInfo(None,self.getObjectId())
+    hbCommand.send()
+    LOGGER.debug("returns")
+
+  """
+  @param node Bus-Knoten Geraete-Adresse.
+  @param function Mod-Bus Funktion.
+  @param address Adresse in Geraet.
+  @param data Daten.
+  """
+  def genericCommand(self, node:int, function:EFunction, address:int, data:bytearray):
+    LOGGER.debug("genericCommand"+" node = "+str(node)+" function = "+str(function)+" address = "+str(address)+" data = "+str(data))
+    hbCommand = HausBusCommand(self.objectId, 3, "genericCommand")
+    hbCommand.addByte(node)
+    hbCommand.addByte(function.value)
+    hbCommand.addWord(address)
+    hbCommand.addBlob(data)
+    ResultWorker()._setResultInfo(None,self.getObjectId())
+    hbCommand.send()
+    LOGGER.debug("returns")
+
 
