@@ -83,6 +83,8 @@ def getBusClassNameFor(classId, functionId):
     return "pyhausbus.de.hausbus.homeassistant.proxy.schalter.data.EvDisabled"
   if (classId==19 and functionId==6):
     return "pyhausbus.de.hausbus.homeassistant.proxy.schalter.commands.ToggleByDuty"
+  if (classId==19 and functionId==205):
+    return "pyhausbus.de.hausbus.homeassistant.proxy.schalter.data.EvToggleByDuty"
   if (classId==17 and functionId==201):
     return "pyhausbus.de.hausbus.homeassistant.proxy.dimmer.data.EvOn"
   if (classId==17 and functionId==1):
@@ -211,6 +213,8 @@ def getBusClassNameFor(classId, functionId):
     return "pyhausbus.de.hausbus.homeassistant.proxy.controller.data.EvSystemVariableChanged"
   if (classId==0 and functionId==20):
     return "pyhausbus.de.hausbus.homeassistant.proxy.controller.commands.ResetOneWireManager"
+  if (classId==0 and functionId==21):
+    return "pyhausbus.de.hausbus.homeassistant.proxy.controller.commands.SetWatchDogTime"
   if (classId==18 and functionId==0):
     return "pyhausbus.de.hausbus.homeassistant.proxy.rollladen.commands.GetConfiguration"
   if (classId==18 and functionId==2):
@@ -621,6 +625,10 @@ def getBusClassNameFor(classId, functionId):
     return "pyhausbus.de.hausbus.homeassistant.proxy.modBusMaster.commands.SetConfiguration"
   if (classId==45 and functionId==128):
     return "pyhausbus.de.hausbus.homeassistant.proxy.modBusMaster.data.Configuration"
+  if (classId==45 and functionId==129):
+    return "pyhausbus.de.hausbus.homeassistant.proxy.modBusMaster.data.GenericResponse"
+  if (classId==45 and functionId==3):
+    return "pyhausbus.de.hausbus.homeassistant.proxy.modBusMaster.commands.GenericCommand"
   if (classId==36 and functionId==200):
     return "pyhausbus.de.hausbus.homeassistant.proxy.analogEingang.data.EvLow"
   if (classId==36 and functionId==201):
@@ -680,7 +688,7 @@ def getBusClassNameFor(classId, functionId):
   if (classId==49 and functionId==129):
     return "pyhausbus.de.hausbus.homeassistant.proxy.pT1000.data.Status"
 
-  return "pyhausbus.de.hausbus.com.GenericBusData"
+  return "pyhausbus.GenericBusData"
 
 def getBusClassNameForClass(classId):
   if (classId==16):
@@ -752,5 +760,5 @@ def getBusClassNameForClass(classId):
   if (classId==49):
     return "pyhausbus.de.hausbus.homeassistant.proxy.PT1000"
 
-  return "pyhausbus.de.hausbus.com.GenericBusData"
+  return "pyhausbus.GenericBusData"
 
