@@ -21,5 +21,13 @@ class ESlotType(Enum):
 
     return ESlotType.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'ESlotType':
+    try:
+      return ESlotType[name]
+    except KeyError:
+      return ESlotType.SER_UNKNOWN 
+
+
 
 
