@@ -7,6 +7,8 @@ class EErrorCode(Enum):
   FAILTURE=2
   OUT_OF_MEMORY=4
   RESULT_NOT_AVAILABLE=12
+  CONFIGURATION_OUT_OF_MEMORY=128
+  ANY_ERROR=255
   SER_UNKNOWN=-1
 
   @staticmethod
@@ -18,5 +20,13 @@ class EErrorCode(Enum):
 
     return EErrorCode.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EErrorCode':
+    try:
+      return EErrorCode[name]
+    except KeyError:
+      return EErrorCode.SER_UNKNOWN 
+
+
 
 
