@@ -16,5 +16,13 @@ class EStatus(Enum):
 
     return EStatus.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EStatus':
+    try:
+      return EStatus[name]
+    except KeyError:
+      return EStatus.SER_UNKNOWN 
+
+
 
 
