@@ -23,5 +23,13 @@ class ESensorType(Enum):
 
     return ESensorType.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'ESensorType':
+    try:
+      return ESensorType[name]
+    except KeyError:
+      return ESensorType.SER_UNKNOWN 
+
+
 
 
