@@ -16,5 +16,13 @@ class ELastEvent(Enum):
 
     return ELastEvent.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'ELastEvent':
+    try:
+      return ELastEvent[name]
+    except KeyError:
+      return ELastEvent.SER_UNKNOWN 
+
+
 
 
