@@ -17,5 +17,13 @@ class EDirection(Enum):
 
     return EDirection.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EDirection':
+    try:
+      return EDirection[name]
+    except KeyError:
+      return EDirection.SER_UNKNOWN 
+
+
 
 
